CpsEvalError

Enum CpsEvalError 

pub enum CpsEvalError {
Show 16 variants MissingFunction { name: String, }, MissingContinuation { function: String, id: CpsContinuationId, }, MissingHandler { function: String, id: CpsHandlerId, }, ContinuationArgumentMismatch { function: String, id: CpsContinuationId, expected: usize, actual: usize, }, FunctionArgumentMismatch { function: String, expected: usize, actual: usize, }, MissingValue { function: String, id: CpsValueId, }, ExpectedPlainValue { function: String, id: CpsValueId, }, ExpectedResumption { function: String, id: CpsValueId, }, UnsupportedPrimitive { op: PrimitiveOp, }, PrimitiveTypeMismatch { op: PrimitiveOp, value: VmValue, }, InvalidPrimitiveArity { op: PrimitiveOp, expected: usize, actual: usize, }, ExpectedRecord { function: String, value: VmValue, }, MissingRecordField { function: String, field: Name, }, MissingGuard, ExpectedGuard { function: String, id: CpsValueId, value: VmValue, }, EscapedScopeReturn { function: String, prompt: u64, target: CpsContinuationId, },
}

Variants



MissingFunction

Fields

name: String


MissingContinuation

Fields

function: String


MissingHandler

Fields

function: String


ContinuationArgumentMismatch

Fields

function: String
expected: usize
actual: usize


FunctionArgumentMismatch

Fields

function: String
expected: usize
actual: usize


MissingValue

Fields

function: String


ExpectedPlainValue

Fields

function: String


ExpectedResumption

Fields

function: String


UnsupportedPrimitive

Fields



PrimitiveTypeMismatch

Fields

value: VmValue


InvalidPrimitiveArity

Fields

expected: usize
actual: usize


ExpectedRecord

Fields

function: String
value: VmValue


MissingRecordField

Fields

function: String
field: Name


MissingGuard



ExpectedGuard

Fields

function: String
value: VmValue


EscapedScopeReturn

A ScopeReturn reached the root without ever finding its prompt in active_handlers. This is a lowering bug — every Perform must lead to an arm whose enclosing handler scope is still on the stack.

Fields

function: String
prompt: u64